summaryrefslogtreecommitdiffstats
path: root/utils
diff options
context:
space:
mode:
authorCorey Hulen <corey@hulen.com>2017-08-22 15:57:02 -0700
committerChristopher Speller <crspeller@gmail.com>2017-08-22 15:57:02 -0700
commit7dad3965a647af56583db8e5061bbef298d23138 (patch)
tree1e1c534ecc3655a50012b3ea2c5d571cf4e97f6f /utils
parentf9632497a4ae7dc85a04274b2794ef8a52e99cb3 (diff)
downloadchat-7dad3965a647af56583db8e5061bbef298d23138.tar.gz
chat-7dad3965a647af56583db8e5061bbef298d23138.tar.bz2
chat-7dad3965a647af56583db8e5061bbef298d23138.zip
Switch hook debug msg to info (#7272)
Diffstat (limited to 'utils')
-rw-r--r--utils/log.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/utils/log.go b/utils/log.go
index ab2750f36..c1f579e9d 100644
--- a/utils/log.go
+++ b/utils/log.go
@@ -11,14 +11,14 @@ import (
l4g "github.com/alecthomas/log4go"
)
// DebugReader logs the content of the io.Reader and returns a new io.Reader
// with the same content as the received io.Reader.
// If you pass reader by reference, it won't be re-created unless the loglevel
// includes Debug.
// If an error is returned, the reader is consumed an cannot be read again.
-func DebugReader(reader io.Reader, message string) (io.Reader, error) {
+func InfoReader(reader io.Reader, message string) (io.Reader, error) {
var err error
- l4g.Debug(func() string {
+ l4g.Info(func() string {
content, err := ioutil.ReadAll(reader)
if err != nil {
return ""
@@ -11,14 +11,14 @@ import (
l4g "github.com/alecthomas/log4go"
)
-// DebugReader logs the content of the io.Reader and returns a new io.Reader
+// InfoReader logs the content of the io.Reader and returns a new io.Reader
// with the same content as the received io.Reader.
// If you pass reader by reference, it won't be re-created unless the loglevel